# Test Coverage Report: excluded packages and modules

Generated: Thu 2013-02-28 16:32 SGT

These packages and modules were excluded from the coverage analysis in `django.conf.settings.COVERAGE_MODULE_EXCLUDES` or they do not contain any executable statements:

- cms
- django.contrib.admin
- django.contrib.admindocs
- django.contrib.auth
- django.contrib.contenttypes
- django.contrib.messages
- django.contrib.sessions
- django.contrib.sitemaps
- django.contrib.sites
- django.contrib.staticfiles
- document_library
- filer
- menus
- mptt
- multilingual_events.admin
- multilingual_events.cms_app
- multilingual_events.cms_plugins
- multilingual_events.fixtures
- multilingual_events.migrations
- multilingual_events.templatetags.__init__
- multilingual_events.tests
- multilingual_events.tests.test_app.__init__
- multilingual_events.tests.test_app.models
- multilingual_events.urls
- sekizai

Back to index.